update static method

Future<void> update(
  1. Contact contact
)

Updates a contact.

Contact must have been fetched using get() or getAll() first. Only the properties that were fetched will be updated. This prevents accidentally overwriting fields that weren't loaded. For example, if you fetched only name and phone, only those fields can be updated; email changes will be ignored.

Implementation

static Future<void> update(Contact contact) => _crud.update(contact);