updateAll static method
Updates multiple contacts in a single batch operation.
All contacts must have been fetched using get() or getAll() with the same
properties parameter. Only the properties that were fetched will be updated.
This prevents accidentally overwriting fields that weren't loaded. For example,
if you fetched only name and phone, only those fields can be updated; email
changes will be ignored.
Implementation
static Future<void> updateAll(List<Contact> contacts) =>
_crud.updateAll(contacts);