toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => JsonHelpers.formatToString('Contact', {
  'id': id,
  'displayName': displayName,
  'photo': photo,
  'name': name,
  'phones': phones.isNotEmpty ? phones : null,
  'emails': emails.isNotEmpty ? emails : null,
  'addresses': addresses.isNotEmpty ? addresses : null,
  'organizations': organizations.isNotEmpty ? organizations : null,
  'websites': websites.isNotEmpty ? websites : null,
  'socialMedias': socialMedias.isNotEmpty ? socialMedias : null,
  'events': events.isNotEmpty ? events : null,
  'relations': relations.isNotEmpty ? relations : null,
  'notes': notes.isNotEmpty ? notes : null,
  'android': android,
  'metadata': metadata,
});