ContactMetadata class

Metadata about a contact, tracking which properties were fetched and account information.

Automatically populated when fetching contacts via FlutterContacts.get or FlutterContacts.getAll. Required when editing contacts to identify which properties to update.

Do not edit or create manually - it's managed automatically by the plugin.

Constructors

ContactMetadata({required Set<ContactProperty> properties, required List<Account> accounts})
const

Properties

accounts List<Account>
Accounts this contact belongs to.
final
hashCode int
The hash code for this object.
no setteroverride
properties Set<ContactProperty>
Properties that were fetched for this contact.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Set<ContactProperty>? properties, List<Account>? accounts}) ContactMetadata
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map json) ContactMetadata