Ringtone class

Information about a ringtone.

uri is always present. All other fields are only populated if withMetadata was true when fetching the ringtone.

Constructors

Ringtone({required String uri, String? title, RingtoneType? type, bool? hasHapticChannels, String? mediaTitle, String? artist, String? album, int? duration, String? displayName, int? size, int? dateAdded, int? dateModified, String? mimeType})
const
Ringtone.fromJson(Map json)
factory

Properties

album String?
Album name (only if withMetadata was true).
final
artist String?
Artist name (only if withMetadata was true).
final
dateAdded int?
Date added timestamp in milliseconds since epoch (only if withMetadata was true).
final
dateModified int?
Date modified timestamp in milliseconds since epoch (only if withMetadata was true).
final
displayName String?
Display name (only if withMetadata was true).
final
duration int?
Duration in milliseconds (only if withMetadata was true).
final
hasHapticChannels bool?
Whether the ringtone contains haptic channels (only if withMetadata was true).
final
hashCode int
The hash code for this object.
no setterinherited
mediaTitle String?
Media title (only if withMetadata was true).
final
mimeType String?
MIME type (only if withMetadata was true).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
File size in bytes (only if withMetadata was true).
final
title String?
Ringtone title/name (only if withMetadata was true).
final
type RingtoneType?
Ringtone type (only if withMetadata was true).
final
uri String
Ringtone URI (always present).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited