getAll static method
Future<List<Contact> >
getAll({
- Set<
ContactProperty> ? properties, - ContactFilter? filter,
- Account? account,
- int? limit,
Gets all contacts matching the criteria.
properties - Properties to fetch. Defaults to none (only ID and display name).
filter - Optional filter (e.g., by name, phone, email, group).
Note: Phone and email filters support partial matching on Android, but only full matching on iOS.
account - Optional account filter. Only returns contact data that exists in that account.
limit - Optional maximum number of contacts to return.
Implementation
static Future<List<Contact>> getAll({
Set<ContactProperty>? properties,
ContactFilter? filter,
Account? account,
int? limit,
}) => _crud.getAll(
properties: properties,
filter: filter,
account: account,
limit: limit,
);