ContactProperties class
Predefined sets of contact properties for common use cases.
Note: Contact IDs and display names are always fetched regardless of the properties specified.
Provides convenient static instances for common property combinations:
- none - No properties (just IDs and display names)
- all - All properties including thumbnail and full-resolution photos
- allProperties - All properties without photos
You can also use Set literals directly in API calls:
FlutterContacts.get(id, properties: {ContactProperty.phone, ContactProperty.email});
Or use predefined sets:
FlutterContacts.get(id, properties: ContactProperties.all);
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
all
→ const Set<
ContactProperty> - All properties including both thumbnail and full-resolution photos.
-
allProperties
→ const Set<
ContactProperty> - All properties without any photos (excludes both thumbnail and full-resolution).
-
none
→ const Set<
ContactProperty> - No properties (just IDs and display names).